typed_descriptors.attr
======================

.. automodule:: typed_descriptors.attr

Attr
----

.. autoclass:: typed_descriptors.attr.Attr
    :show-inheritance:
    :members:
    :special-members: __init__, __set__, __get__

T_contra
--------

.. autodata:: typed_descriptors.attr.T_contra

ValidatorFunction
-----------------

.. autoclass:: typed_descriptors.attr.ValidatorFunction
    :show-inheritance:
    :members:
